@@ -1,6 +1,6 @@
 # flake8: noqa
 from miio.protocol import Message, Utils
-from miio.vacuumcontainers import (VacuumStatus, ConsumableStatus,
+from miio.vacuumcontainers import (VacuumStatus, ConsumableStatus, DNDStatus,
                                    CleaningDetails, CleaningSummary, Timer)
 from miio.vacuum import Vacuum, VacuumException
 from miio.plug import Plug
@@ -8,12 +8,15 @@ from miio.plug_v1 import PlugV1
 from miio.airpurifier import AirPurifier
 from miio.airhumidifier import AirHumidifier
 from miio.waterpurifier import WaterPurifier
-from miio.strip import Strip
+from miio.powerstrip import PowerStrip
 from miio.ceil import Ceil
+from miio.philips_bulb import PhilipsBulb
 from miio.philips_eyecare import PhilipsEyecare
 from miio.chuangmi_ir import ChuangmiIr
 from miio.fan import Fan
 from miio.wifispeaker import WifiSpeaker
+from miio.airqualitymonitor import AirQualityMonitor
+from miio.airconditioningcompanion import AirConditioningCompanion
 from miio.yeelight import Yeelight
 from miio.device import Device, DeviceException
 from miio.discovery import Discovery
