@@ -2,11 +2,15 @@ import logging
 import enum
 from typing import Any, Dict, Optional
 from collections import defaultdict
-from .device import Device
+from .device import Device, DeviceException
 
 _LOGGER = logging.getLogger(__name__)
 
 
+class AirHumidifierException(DeviceException):
+    pass
+
+
 class OperationMode(enum.Enum):
     Silent = 'silent'
     Medium = 'medium'
@@ -23,60 +27,108 @@ class AirHumidifierStatus:
     """Container for status reports from the air humidifier."""
 
     def __init__(self, data: Dict[str, Any]) -> None:
+        """
+        Response of a Air Humidifier (zhimi.humidifier.v1):
+
+        {'power': 'off', 'mode': 'high', 'temp_dec': 294,
+         'humidity': 33, 'buzzer': 'on', 'led_b': 0,
+         'child_lock': 'on', 'limit_hum': 40, 'trans_level': 85}
+
+        TODO: Features of the Air Humidifier Ca (zhimi.humidifier.ca1):
+          - Same properties: power, mode, temp_dec, humidity,
+            buzzer, led_b, child_lock, limit_hum
+          - Additional properties: speed, depth, dry, hw_version,
+            use_time, button_pressed
+          - Operation modes: auto, high, medium, silent
+          - Additional setters: set_dry on/off
+        """
+
         self.data = data
 
     @property
     def power(self) -> str:
+        """Power state."""
         return self.data["power"]
 
     @property
     def is_on(self) -> bool:
+        """True if device is turned on."""
         return self.power == "on"
 
     @property
     def mode(self) -> OperationMode:
+        """Operation mode. Can be either silent, medium or high."""
         return OperationMode(self.data["mode"])
 
     @property
     def temperature(self) -> Optional[float]:
+        """Current temperature, if available."""
         if self.data["temp_dec"] is not None:
             return self.data["temp_dec"] / 10.0
         return None
 
     @property
     def humidity(self) -> int:
+        """Current humidity."""
         return self.data["humidity"]
 
     @property
     def buzzer(self) -> bool:
+        """True if buzzer is turned on."""
         return self.data["buzzer"] == "on"
 
-    @property
-    def led(self) -> bool:
-        return self.data["led"] == "on"
-
     @property
     def led_brightness(self) -> Optional[LedBrightness]:
+        """LED brightness if available."""
         if self.data["led_b"] is not None:
             return LedBrightness(self.data["led_b"])
         return None
 
+    @property
+    def child_lock(self) -> bool:
+        """Return True if child lock is on."""
+        return self.data["child_lock"] == "on"
+
+    @property
+    def target_humidity(self) -> int:
+        """Target humiditiy. Can be either 30, 40, 50, 60, 70, 80 percent."""
+        return self.data["limit_hum"]
+
+    @property
+    def trans_level(self) -> int:
+        """The meaning of the property is unknown."""
+        return self.data["trans_level"]
+
     def __str__(self) -> str:
-        s = "<AirHumidiferStatus power=%s, mode=%s, temperature=%s, " \
-            "humidity=%s%%, led=%s, led_brightness=%s, buzzer=%s>" % \
-            (self.power, self.mode, self.temperature,
-             self.humidity, self.led, self.led_brightness, self.buzzer)
+        s = "<AirHumidiferStatus power=%s, " \
+            "mode=%s, " \
+            "temperature=%s, " \
+            "humidity=%s%%, " \
+            "led_brightness=%s, " \
+            "buzzer=%s, " \
+            "child_lock=%s, " \
+            "target_humidity=%s%%, " \
+            "trans_level=%s>" % \
+            (self.power,
+             self.mode,
+             self.temperature,
+             self.humidity,
+             self.led_brightness,
+             self.buzzer,
+             self.child_lock,
+             self.target_humidity,
+             self.trans_level)
         return s
 
 
 class AirHumidifier(Device):
-    """Main class representing the air humidifier."""
+    """Implementation of Xiaomi Mi Air Humidifier."""
 
     def status(self) -> AirHumidifierStatus:
         """Retrieve properties."""
 
         properties = ['power', 'mode', 'temp_dec', 'humidity', 'buzzer',
-                      'led_b', ]
+                      'led_b', 'child_lock', 'limit_hum', 'trans_level', ]
 
         values = self.send(
             "get_prop",
@@ -110,16 +162,24 @@ class AirHumidifier(Device):
         """Set led brightness."""
         return self.send("set_led_b", [brightness.value])
 
-    def set_led(self, led: bool):
-        """Turn led on/off."""
-        if led:
-            return self.send("set_led", ['on'])
-        else:
-            return self.send("set_led", ['off'])
-
     def set_buzzer(self, buzzer: bool):
         """Set buzzer on/off."""
         if buzzer:
             return self.send("set_buzzer", ["on"])
         else:
             return self.send("set_buzzer", ["off"])
+
+    def set_child_lock(self, lock: bool):
+        """Set child lock on/off."""
+        if lock:
+            return self.send("set_child_lock", ["on"])
+        else:
+            return self.send("set_child_lock", ["off"])
+
+    def set_target_humidity(self, humidity: int):
+        """Set the target humidity."""
+        if humidity not in [30, 40, 50, 60, 70, 80]:
+            raise AirHumidifierException(
+                "Invalid target humidity: %s" % humidity)
+
+        return self.send("set_limit_hum", [humidity])
