@@ -99,7 +99,7 @@ class Device:
     This class should not be initialized directly but a device-specific class inheriting
     it should be used instead of it."""
     def __init__(self, ip: str = None, token: str = None,
-                 start_id: int=0, debug: int=0) -> None:
+                 start_id: int=0, debug: int=0, lazy_discover: bool=True) -> None:
         """
         Create a :class:`Device` instance.
         :param ip: IP address or a hostname for the device
@@ -114,8 +114,10 @@ class Device:
         if token is not None:
             self.token = bytes.fromhex(token)
         self.debug = debug
+        self.lazy_discover = lazy_discover
 
         self._timeout = 5
+        self._discovered = False
         self._device_ts = None  # type: datetime.datetime
         self.__id = start_id
         self._device_id = None
@@ -133,6 +135,7 @@ class Device:
         if m is not None:
             self._device_id = m.header.value.device_id
             self._device_ts = m.header.value.ts
+            self._discovered = True
             if self.debug > 1:
                 _LOGGER.debug(m)
             _LOGGER.debug("Discovered %s with ts: %s, token: %s",
@@ -201,7 +204,9 @@ class Device:
         :param dict parameters: Parameters to send, or an empty list FIXME
         :param retry_count: How many times to retry in case of failure
         :raises DeviceException: if an error has occured during communication."""
-        self.do_discover()
+
+        if not self.lazy_discover or not self._discovered:
+            self.do_discover()
 
         cmd = {
             "id": self._id,
@@ -264,6 +269,7 @@ class Device:
                 _LOGGER.warning("Retrying with incremented id, "
                                 "retries left: %s", retry_count)
                 self.__id += 100
+                self._discovered = False
                 return self.send(command, parameters, retry_count - 1)
             raise DeviceException("No response from the device") from ex
 
@@ -287,7 +293,7 @@ class Device:
         """Increment and return the sequence id."""
         self.__id += 1
         if self.__id >= 9999:
-            self.__id = 0
+            self.__id = 1
         return self.__id
 
     @property
