@@ -5,47 +5,25 @@ import pretty_cron
 import ast
 import sys
 import json
-import ipaddress
+import time
+import pathlib
+from appdirs import user_cache_dir
 from pprint import pformat as pf
 from typing import Any  # noqa: F401
-
-
-if sys.version_info < (3, 4):
-    print("To use this script you need python 3.4 or newer, got %s" %
-          sys.version_info)
-    sys.exit(1)
-
+from miio.click_common import (ExceptionHandlerGroup, validate_ip,
+                               validate_token)
 import miio  # noqa: E402
 
 _LOGGER = logging.getLogger(__name__)
 pass_dev = click.make_pass_decorator(miio.Device, ensure=True)
 
 
-def validate_ip(ctx, param, value):
-    if value is None:
-        return value
-    try:
-        ipaddress.ip_address(value)
-        return value
-    except ValueError as ex:
-        raise click.BadParameter("Invalid IP: %s" % ex)
-
-
-def validate_token(ctx, param, value):
-    if value is None:
-        return value
-    token_len = len(value)
-    if token_len != 32:
-        raise click.BadParameter("Token length != 32 chars: %s" % token_len)
-    return value
-
-
-@click.group(invoke_without_command=True)
+@click.group(invoke_without_command=True, cls=ExceptionHandlerGroup)
 @click.option('--ip', envvar="MIROBO_IP", callback=validate_ip)
 @click.option('--token', envvar="MIROBO_TOKEN", callback=validate_token)
 @click.option('-d', '--debug', default=False, count=True)
 @click.option('--id-file', type=click.Path(dir_okay=False, writable=True),
-              default='/tmp/python-mirobo.seq')
+              default=user_cache_dir('python-miio') + '/python-mirobo.seq')
 @click.version_option()
 @click.pass_context
 def cli(ctx, ip: str, token: str, debug: int, id_file: str):
@@ -72,8 +50,8 @@ def cli(ctx, ip: str, token: str, debug: int, id_file: str):
             start_id = x.get("seq", 0)
             manual_seq = x.get("manual_seq", 0)
             _LOGGER.debug("Read stored sequence ids: %s", x)
-    except (FileNotFoundError, TypeError, ValueError) as ex:
-        _LOGGER.error("Unable to read the stored msgid: %s", ex)
+    except (FileNotFoundError, TypeError, ValueError):
+        pass
 
     vac = miio.Vacuum(ip, token, start_id, debug)
 
@@ -95,6 +73,12 @@ def cleanup(vac: miio.Vacuum, **kwargs):
     id_file = kwargs['id_file']
     seqs = {'seq': vac.raw_id, 'manual_seq': vac.manual_seqnum}
     _LOGGER.debug("Writing %s to %s", seqs, id_file)
+    path_obj = pathlib.Path(id_file)
+    dir = path_obj.parents[0]
+    try:
+        dir.mkdir(parents=True)
+    except FileExistsError:
+        pass  # after dropping py3.4 support, use exist_ok for mkdir
     with open(id_file, 'w') as f:
         json.dump(seqs, f)
 
@@ -392,10 +376,14 @@ def map(vac: miio.Vacuum):
 @pass_dev
 def info(vac: miio.Vacuum):
     """Return device information."""
-    res = vac.info()
+    try:
+        res = vac.info()
 
-    click.echo("%s" % res)
-    _LOGGER.debug("Full response: %s", pf(res.raw))
+        click.echo("%s" % res)
+        _LOGGER.debug("Full response: %s", pf(res.raw))
+    except TypeError:
+        click.echo("Unable to fetch info, this can happen when the vacuum "
+                   "is not connected to the Xiaomi cloud.")
 
 
 @cli.command()
@@ -420,12 +408,44 @@ def cleaning_history(vac: miio.Vacuum):
 
 
 @cli.command()
+@click.argument('volume', type=int, required=False)
+@click.option('--test', 'test_mode', is_flag=True, help="play a test tune")
 @pass_dev
-def sound(vac: miio.Vacuum):
-    """Query sound settings."""
-    click.echo(vac.sound_info())
+def sound(vac: miio.Vacuum, volume: int, test_mode: bool):
+    """Query and change sound settings."""
+    if volume is not None:
+        click.echo("Setting sound volume to %s" % volume)
+        vac.set_sound_volume(volume)
+    if test_mode:
+        vac.test_sound_volume()
+    click.echo("Current sound: %s" % vac.sound_info())
+    click.echo("Current volume: %s" % vac.sound_volume())
+    click.echo("Install progress: %s" % vac.sound_install_progress())
 
 
+@cli.command()
+@click.argument('url')
+@click.argument('md5sum')
+@click.argument('sid', type=int)
+@pass_dev
+def install_sound(vac: miio.Vacuum, url: str, md5sum: str, sid: int):
+    """Install a sound."""
+    click.echo("Installing from %s (md5: %s) for id %s" % (url, md5sum, sid))
+    click.echo(vac.install_sound(url, md5sum, sid))
+
+    progress = vac.sound_install_progress()
+    while progress.is_installing:
+        print(progress)
+        progress = vac.sound_install_progress()
+        time.sleep(0.1)
+
+    progress = vac.sound_install_progress()
+
+    if progress.progress == 100 and progress.error == 0:
+        click.echo("Installation of sid '%s' complete!" % progress.sid)
+    else:
+        click.echo("Error during installation: %s" % progress.error)
+
 @cli.command()
 @pass_dev
 def serial_number(vac: miio.Vacuum):
